#include<cstdio>
#include<cstdlib>
#include<cassert>
#include<cstring>
#include<cmath>
#define MAX(a, b) ((a) > (b) ? (a) : (b))
#define MIN(a, b) ((a) < (b) ? (a) : (b))

enum {
  DIGITS_IN_BASE = 4,
  BASE = 10000,
  MAXN = 500 * 1000 + 1
};

//---------------------- COMMON FUNCTIONS ----------------------------

const int ONE = 1;

char string_number[MAXN + 1];

// a should have enough capacity
void read_number(int *a, int *size) {
  scanf("%s", string_number);
  int real_size = 0;
  for (int i = strlen(string_number); i > 0; i -= DIGITS_IN_BASE) {
    string_number[i] = 0;
    a[real_size++] = atoi(i >= DIGITS_IN_BASE ? string_number + i - DIGITS_IN_BASE : string_number);
  }
  *size = real_size;
}

void write_number(const int *a, int size) {
  if (size == 0) {
    printf("0\n");
    return;
  }
  printf("%d", a[size - 1]);
  for (int i = size - 2; i >= 0; --i) {
    printf("%04d", a[i]);
  }
  printf("\n");
}

void set_size(const int *result, int size, int *result_size) {
  int real_size = size;
  while (real_size > 0 && !result[real_size - 1]) {
    --real_size;
  }
  *result_size = real_size;
}

int compare(const int *a, int a_size, const int *b, int b_size) {
  while (a_size > 0 && a_size > b_size) {
    if (a[--a_size]) {
      return 1;
    }
  }

  while (b_size > 0 && b_size > a_size) {
    if (b[--b_size]) {
      return -1;
    }
  }

  // now sizes are equal    
  int a_digit, b_digit;
  for (int i = a_size - 1; i >= 0; --i) {
    a_digit = a[i];
    b_digit = b[i];
    if (a_digit < b_digit) {
      return -1;
    }
    if (a_digit > b_digit) {
      return 1;
    }
  }
  return 0;
}

// a must be >= b
void inplace_subtract(int *a, int a_size, const int *b, int b_size, int *result_size) {
  int carry = 0, diff;
  for (int i = 0; i < b_size || carry; ++i) {
    diff = a[i] - carry - (i < b_size ? b[i] : 0);
    carry = diff < 0;
    if (carry) {
      diff += BASE;
    }
    a[i] = diff;
  }
  set_size(a, a_size, result_size);
}

// a must be long enough to contain the result
void inplace_add(int *a, int a_size, const int *b, int b_size, int *result_size) {
  int i, carry = 0;
  for (i = 0; i < MAX(a_size, b_size) || carry; ++i) {
    a[i] = (i < a_size ? a[i] : 0) + carry + (i < b_size ? b[i] : 0);
    carry = a[i] >= BASE;
    if (carry) {
      a[i] -= BASE;
    }
  }
  *result_size = i;
}

void multiply_by_short(const int *a, int a_size, int b, int *result, int *result_size) {
  if (a_size == 0) {
    *result_size = 0;
    return;
  }
  int i, sum, carry = 0;
  for (i = 0; i < a_size || carry; ++i) {
    sum = (i < a_size ? a[i] : 0) * b + carry;
    carry = sum / BASE;
    result[i] = sum - carry * BASE;
  }
  *result_size = i;
}

// returns residual
int inplace_divide_by_short(int *a, int a_size, int b, int *result_size) {
  if (a_size == 0) {
    *result_size = 0;
    return 0;
  }
  int sum, carry = 0;
  for (int i = a_size - 1; i >= 0; --i) {
    sum = a[i] + carry * BASE;
    a[i] = sum / b;
    carry = sum - a[i] * b;
  }
  set_size(a, a_size, result_size);
  return carry;
}

//--------------------- MULTIPLICATION -------------------------------

// BASECASE MULTIPLICATION
long long basecase_intermediate_result[2 * MAXN];

// result must have capacity for at least a_size + b_size elements, function fills them
void multiply(const int *a, int a_size, const int *b, int b_size, int *result, int *result_size) {
  if (a_size == 0 || b_size == 0) {
    *result_size = 0;
    return;
  }

  memset(basecase_intermediate_result, 0, (a_size + b_size) * sizeof(long long));
  for (int i = 0; i < a_size; ++i) {
    for (int j = 0; j < b_size; ++j) {
      basecase_intermediate_result[i + j] += a[i] * b[j];
    }
  }
  long long sum, carry = 0;
  for (int i = 0; i < a_size + b_size; ++i) {
    sum = basecase_intermediate_result[i] + carry;
    carry = sum / BASE;
    result[i] = sum - carry * BASE;
  }

  set_size(result, a_size + b_size, result_size);
}

//--------------------- SQUARE ROOT -------------------------------

int left[2 * MAXN], right[2 * MAXN], m[2 * MAXN], mult[2 * MAXN];
int left_size, right_size, m_size, mult_size;

void binsearch_square_root(int *a, int a_size, int *result, int *result_size, int *residue, int *residue_size) {
  if (a_size == 0) {
    *result_size = 0;
    *residue_size = 0;
    return;
  }

  if (a_size == 1) {
    int s = sqrt((double)a[0]);
    *result_size = 1;
    result[0] = s;
    residue[0] = a[0] - s * s;
    set_size(residue, 1, residue_size);
    return;
  }

  int base_pow = (a_size + 1) >> 1;
  memset(right, 0, base_pow * sizeof(int));
  right[base_pow] = 1;
  right_size = base_pow + 1;

  memset(left, 0, (base_pow - 1) * sizeof(int));
  left[base_pow - 1] = 1;
  left_size = base_pow;

  while (true) {
    memcpy(m, left, left_size * sizeof(int));
    inplace_add(m, left_size, right, right_size, &m_size);
    inplace_divide_by_short(m, m_size, 2, &m_size);
    if (compare(m, m_size, left, left_size) == 0) {
      break;
    }

    multiply(m, m_size, m, m_size, mult, &mult_size);
    if (compare(mult, mult_size, a, a_size) <= 0) {
      memcpy(left, m, m_size * sizeof(int));
      left_size = m_size;
    }
    else {
      memcpy(right, m, m_size * sizeof(int));
      right_size = m_size;
    }
  }

  memcpy(result, left, left_size * sizeof(int));
  *result_size = left_size;

  multiply(result, *result_size, result, *result_size, mult, &mult_size);

  memcpy(residue, a, a_size * sizeof(int));
  *residue_size = a_size;
  inplace_subtract(residue, *residue_size, mult, mult_size, residue_size);
}

int n[MAXN], sqrt_s[2 * MAXN], sqrt_r[2 * MAXN], s_plus1_times2[2 * MAXN];
int size, s_size, r_size, s_plus1_times2_size;

int main() {  
  read_number(n, &size);
  binsearch_square_root(n, size, sqrt_s, &s_size, sqrt_r, &r_size);  
  if (r_size == 0) {
    printf("1\n");
    return 0;
  }
  inplace_add(sqrt_s, s_size, &ONE, 1, &s_size);
  if (compare(sqrt_r, r_size, sqrt_s, s_size) <= 0) {
    write_number(sqrt_r, r_size);
  } else {
    multiply_by_short(sqrt_s, s_size, 2, s_plus1_times2, &s_plus1_times2_size);
    inplace_subtract(s_plus1_times2, s_plus1_times2_size, sqrt_r, r_size, &s_plus1_times2_size);
    write_number(s_plus1_times2, s_plus1_times2_size);
  }  
  return 0;
}